/*
 * Copyright (C) 2010 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dalvik.bytecode;

/**
 * Information about Dalvik opcodes.
 */
public final class OpcodeInfo {
    /**
     * The maximum possible value of a Dalvik opcode.
     *
     * <p><b>Note:</b>: This is constant in any given VM incarnation,
     * but it is subject to change over time, so it is not appropriate
     * to represent as a compile-time constant value.</p>
     */
    public static final int MAXIMUM_VALUE = getMaximumValue();

    /**
     * Gets the maximum possible value of a Dalvik opcode.
     *
     * @see #MAXIMUM_VALUE
     *
     * @return the maximum possible value of a Dalvik opcode
     */
    private static int getMaximumValue() {
        // TODO: Make this constant be generated by opcode-gen.
        return 255;
    }

    /**
     * This class is not instantiable.
     */
    private OpcodeInfo() {
        // This space intentionally left blank.
    }
}
